==> zio-aws-sagemaker_3-5.17.295.15-sources.jar: zio/aws/sagemaker/model/AppDetails.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  CreationTime,
  AppName,
  UserProfileName,
  DomainId
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class AppDetails(
    domainId: Optional[DomainId] = Optional.Absent,
    userProfileName: Optional[UserProfileName] = Optional.Absent,
    appType: Optional[zio.aws.sagemaker.model.AppType] = Optional.Absent,
    appName: Optional[AppName] = Optional.Absent,
    status: Optional[zio.aws.sagemaker.model.AppStatus] = Optional.Absent,
    creationTime: Optional[CreationTime] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AppDetails = {
    import AppDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AppDetails
      .builder()
      .optionallyWith(
        domainId.map(value => DomainId.unwrap(value): java.lang.String)
      )(_.domainId)
      .optionallyWith(
        userProfileName.map(value =>
          UserProfileName.unwrap(value): java.lang.String
        )
      )(_.userProfileName)
      .optionallyWith(appType.map(value => value.unwrap))(_.appType)
      .optionallyWith(
        appName.map(value => AppName.unwrap(value): java.lang.String)
      )(_.appName)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        creationTime.map(value => CreationTime.unwrap(value): Instant)
      )(_.creationTime)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AppDetails.ReadOnly =
    zio.aws.sagemaker.model.AppDetails.wrap(buildAwsValue())
}
object AppDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AppDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AppDetails =
      zio.aws.sagemaker.model.AppDetails(
        domainId.map(value => value),
        userProfileName.map(value => value),
        appType.map(value => value),
        appName.map(value => value),
        status.map(value => value),
        creationTime.map(value => value)
      )
    def domainId: Optional[DomainId]
    def userProfileName: Optional[UserProfileName]
    def appType: Optional[zio.aws.sagemaker.model.AppType]
    def appName: Optional[AppName]
    def status: Optional[zio.aws.sagemaker.model.AppStatus]
    def creationTime: Optional[CreationTime]
    def getDomainId: ZIO[Any, AwsError, DomainId] =
      AwsError.unwrapOptionField("domainId", domainId)
    def getUserProfileName: ZIO[Any, AwsError, UserProfileName] =
      AwsError.unwrapOptionField("userProfileName", userProfileName)
    def getAppType: ZIO[Any, AwsError, zio.aws.sagemaker.model.AppType] =
      AwsError.unwrapOptionField("appType", appType)
    def getAppName: ZIO[Any, AwsError, AppName] =
      AwsError.unwrapOptionField("appName", appName)
    def getStatus: ZIO[Any, AwsError, zio.aws.sagemaker.model.AppStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreationTime: ZIO[Any, AwsError, CreationTime] =
      AwsError.unwrapOptionField("creationTime", creationTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AppDetails
  ) extends zio.aws.sagemaker.model.AppDetails.ReadOnly {
    override val domainId: Optional[DomainId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainId())
      .map(value => zio.aws.sagemaker.model.primitives.DomainId(value))
    override val userProfileName: Optional[UserProfileName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userProfileName())
        .map(value => zio.aws.sagemaker.model.primitives.UserProfileName(value))
    override val appType: Optional[zio.aws.sagemaker.model.AppType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.appType())
        .map(value => zio.aws.sagemaker.model.AppType.wrap(value))
    override val appName: Optional[AppName] = zio.aws.core.internal
      .optionalFromNullable(impl.appName())
      .map(value => zio.aws.sagemaker.model.primitives.AppName(value))
    override val status: Optional[zio.aws.sagemaker.model.AppStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.sagemaker.model.AppStatus.wrap(value))
    override val creationTime: Optional[CreationTime] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.sagemaker.model.primitives.CreationTime(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AppDetails
  ): zio.aws.sagemaker.model.AppDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_3-5.19.17.2-sources.jar: zio/aws/sagemaker/model/AppDetails.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  CreationTime,
  SpaceName,
  DomainId,
  AppName,
  UserProfileName
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class AppDetails(
    domainId: Optional[DomainId] = Optional.Absent,
    userProfileName: Optional[UserProfileName] = Optional.Absent,
    appType: Optional[zio.aws.sagemaker.model.AppType] = Optional.Absent,
    appName: Optional[AppName] = Optional.Absent,
    status: Optional[zio.aws.sagemaker.model.AppStatus] = Optional.Absent,
    creationTime: Optional[CreationTime] = Optional.Absent,
    spaceName: Optional[SpaceName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AppDetails = {
    import AppDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AppDetails
      .builder()
      .optionallyWith(
        domainId.map(value => DomainId.unwrap(value): java.lang.String)
      )(_.domainId)
      .optionallyWith(
        userProfileName.map(value =>
          UserProfileName.unwrap(value): java.lang.String
        )
      )(_.userProfileName)
      .optionallyWith(appType.map(value => value.unwrap))(_.appType)
      .optionallyWith(
        appName.map(value => AppName.unwrap(value): java.lang.String)
      )(_.appName)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        creationTime.map(value => CreationTime.unwrap(value): Instant)
      )(_.creationTime)
      .optionallyWith(
        spaceName.map(value => SpaceName.unwrap(value): java.lang.String)
      )(_.spaceName)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AppDetails.ReadOnly =
    zio.aws.sagemaker.model.AppDetails.wrap(buildAwsValue())
}
object AppDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AppDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AppDetails =
      zio.aws.sagemaker.model.AppDetails(
        domainId.map(value => value),
        userProfileName.map(value => value),
        appType.map(value => value),
        appName.map(value => value),
        status.map(value => value),
        creationTime.map(value => value),
        spaceName.map(value => value)
      )
    def domainId: Optional[DomainId]
    def userProfileName: Optional[UserProfileName]
    def appType: Optional[zio.aws.sagemaker.model.AppType]
    def appName: Optional[AppName]
    def status: Optional[zio.aws.sagemaker.model.AppStatus]
    def creationTime: Optional[CreationTime]
    def spaceName: Optional[SpaceName]
    def getDomainId: ZIO[Any, AwsError, DomainId] =
      AwsError.unwrapOptionField("domainId", domainId)
    def getUserProfileName: ZIO[Any, AwsError, UserProfileName] =
      AwsError.unwrapOptionField("userProfileName", userProfileName)
    def getAppType: ZIO[Any, AwsError, zio.aws.sagemaker.model.AppType] =
      AwsError.unwrapOptionField("appType", appType)
    def getAppName: ZIO[Any, AwsError, AppName] =
      AwsError.unwrapOptionField("appName", appName)
    def getStatus: ZIO[Any, AwsError, zio.aws.sagemaker.model.AppStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreationTime: ZIO[Any, AwsError, CreationTime] =
      AwsError.unwrapOptionField("creationTime", creationTime)
    def getSpaceName: ZIO[Any, AwsError, SpaceName] =
      AwsError.unwrapOptionField("spaceName", spaceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AppDetails
  ) extends zio.aws.sagemaker.model.AppDetails.ReadOnly {
    override val domainId: Optional[DomainId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainId())
      .map(value => zio.aws.sagemaker.model.primitives.DomainId(value))
    override val userProfileName: Optional[UserProfileName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userProfileName())
        .map(value => zio.aws.sagemaker.model.primitives.UserProfileName(value))
    override val appType: Optional[zio.aws.sagemaker.model.AppType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.appType())
        .map(value => zio.aws.sagemaker.model.AppType.wrap(value))
    override val appName: Optional[AppName] = zio.aws.core.internal
      .optionalFromNullable(impl.appName())
      .map(value => zio.aws.sagemaker.model.primitives.AppName(value))
    override val status: Optional[zio.aws.sagemaker.model.AppStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.sagemaker.model.AppStatus.wrap(value))
    override val creationTime: Optional[CreationTime] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.sagemaker.model.primitives.CreationTime(value))
    override val spaceName: Optional[SpaceName] = zio.aws.core.internal
      .optionalFromNullable(impl.spaceName())
      .map(value => zio.aws.sagemaker.model.primitives.SpaceName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AppDetails
  ): zio.aws.sagemaker.model.AppDetails.ReadOnly = new Wrapper(impl)
}
